@@ -33,14 +33,3 @@ test_that("Lambda_inv_linear_form works", {
     Lambda_inv_linear_form(z = rep(0, 10), alpha = 0, beta = 0, t0 = 1)
   )
 })
-
-
-test_that("get_step_majorizer() works", {
-  expect_no_error(l1 <- get_step_majorizer(
-    fun = abs,
-    breaks = -10:10, is_monotone = FALSE, K = 1
-  ))
-  l1_fun <- stats::approxfun(y = l1, x = -10:9, method = "constant", rule = 2)
-  x <- seq(-10, 10, length.out = 1000)
-  expect_true(sum(l1_fun(x) < abs(x)) == 0)
-})
