@@ -1,4 +1,5 @@
 test_that("ztppp() arguments work", {
+  set.seed(123)
   expect_no_error(df0 <- ztppp(range_t = c(0, 10), rate = 1, atmost1 = TRUE))
   check_ppp_sample_validity(times = df0, t_min = 0, t_max = 10, atleast1 = TRUE, atmost1 = TRUE)
 
@@ -9,10 +10,4 @@ test_that("ztppp() arguments work", {
   S1 <- methods::new("rstream.mrg32k3a")
   expect_no_error(df2 <- ppp_sequential(range_t = c(0, 10), rate = 1, rng_stream = S1))
   check_ppp_sample_validity(times = df2, t_min = 0, t_max = 10, atleast1 = TRUE)
-
-
-  # # check RNGClass
-  # expect_no_error(S2 <- readRDS(file.path("example_RNGCLass.rds"))$unpack())
-  # expect_no_error(df3 <- ppp_sequential(range_t = c(0, 10), rate = 1, rng_stream = S2))
-  # check_ppp_sample_validity(times = df3, t_min = 0, t_max = 10, atleast1 = TRUE)
 })
